diff -pruN 1.3.93-2/CHANGES.md 1.4.2-1/CHANGES.md
--- 1.3.93-2/CHANGES.md	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/CHANGES.md	2019-12-09 10:40:31.000000000 +0000
@@ -1,7 +1,33 @@
 colored
 =====
 
+version 1.4.2 - *(09-12-2019)*
+-----
+
+### Updated
+- Python 3 compatibility
+- setup.py file 
+
+
+Version 1.4.1 - *(28-10-2019)*
+-----
+
+### Fixed
+- UnsupportedOperation: fileno when detecting TTY #14
+
+Version 1.4.0 - *(02-10-2019)*
+-----
+
+### Added
+- Ensure package data is included !7
+- Converted old package spec files to new format !9
+- Hex improvements !11
+- Enable colors in Windows' terminal !12
+- Added an option to make colored tty aware !13
+
 Version 1.3.93 - *(06-07-2018)*
+-----
+
 ### Fixed
 - Typo in MANIFEST file
 
diff -pruN 1.3.93-2/colored/back.py 1.4.2-1/colored/back.py
--- 1.3.93-2/colored/back.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/colored/back.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 
diff -pruN 1.3.93-2/colored/colored.py 1.4.2-1/colored/colored.py
--- 1.3.93-2/colored/colored.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/colored/colored.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,10 +1,17 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import platform
 
 from .hex import HEX
+import sys
 
 
+TTY_AWARE = False
+IS_TTY = sys.stdout.isatty() and sys.stderr.isatty()
+
+_win_vterm_mode = None
+
 class colored(object):
 
     def __init__(self, color):
@@ -12,6 +19,7 @@ class colored(object):
         self.ESC = "\x1b["
         self.END = "m"
         self.color = color
+        self.enable_windows_terminal_mode()
 
         if str(color).startswith("#"):
             self.HEX = HEX(color.lower())
@@ -279,6 +287,8 @@ class colored(object):
 
     def attribute(self):
         """Set or reset attributes"""
+        if TTY_AWARE and not IS_TTY:
+            return ""
 
         paint = {
             "bold": self.ESC + "1" + self.END,
@@ -312,6 +322,8 @@ class colored(object):
 
     def foreground(self):
         """Print 256 foreground colors"""
+        if TTY_AWARE and not IS_TTY:
+            return ""
         code = self.ESC + "38;5;"
         if str(self.color).isdigit():
             self.reverse_dict()
@@ -324,6 +336,8 @@ class colored(object):
 
     def background(self):
         """Print 256 background colors"""
+        if TTY_AWARE and not IS_TTY:
+            return ""
         code = self.ESC + "48;5;"
         if str(self.color).isdigit():
             self.reverse_dict()
@@ -338,6 +352,45 @@ class colored(object):
         """reverse dictionary"""
         self.reserve_paint = dict(zip(self.paint.values(), self.paint.keys()))
 
+    def enable_windows_terminal_mode(self):
+        '''Enable virtual terminal processing in windows terminal. Does
+        nothing if not on Windows. This is based on the rejected
+        enhancement <https://bugs.python.org/issue29059>.'''
+        global _win_vterm_mode
+        if _win_vterm_mode != None:
+            return _win_vterm_mode
+
+        # Note: Cygwin should return something like "CYGWIN_NT..."
+        _win_vterm_mode = platform.system().lower() == 'windows'
+        if _win_vterm_mode == False:
+            return
+
+        from ctypes import windll, c_int, byref, c_void_p
+        ENABLE_VIRTUAL_TERMINAL_PROCESSING = 0x0004
+        INVALID_HANDLE_VALUE = c_void_p(-1).value
+        STD_OUTPUT_HANDLE = c_int(-11)
+
+        hStdout = windll.kernel32.GetStdHandle(STD_OUTPUT_HANDLE)
+        if hStdout == INVALID_HANDLE_VALUE:
+            _win_vterm_mode = False
+            return
+
+        mode = c_int(0)
+        ok = windll.kernel32.GetConsoleMode(c_int(hStdout), byref(mode))
+        if not ok:
+            _win_vterm_mode = False
+            return
+
+        mode = c_int(mode.value | ENABLE_VIRTUAL_TERMINAL_PROCESSING)
+        ok = windll.kernel32.SetConsoleMode(c_int(hStdout), mode)
+        if not ok:
+            # Something went wrong, proably an too old version
+            # that doesn't support the VT100 mode.
+            # To be more certain we could check kernel32.GetLastError
+            # for STATUS_INVALID_PARAMETER, but since we only enable
+            # one flag we can be certain enough.
+            _win_vterm_mode = False
+            return
 
 def attr(color):
     """alias for colored().attribute()"""
@@ -375,3 +428,10 @@ def stylize_interactive(text, styles, re
     # see: https://gitlab.com/dslackw/colored/issues/5
     terminator = _c0wrap(attr("reset")) if reset else ""
     return "{}{}{}".format(_c0wrap(styles), text, terminator)
+
+def set_tty_aware():
+    """Makes all interactions here tty aware.  This means that if either
+    stdout or stderr are directed to something other than a tty,
+    colorization will not be added."""
+    global TTY_AWARE
+    TTY_AWARE = True
diff -pruN 1.3.93-2/colored/colors.py 1.4.2-1/colored/colors.py
--- 1.3.93-2/colored/colors.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/colored/colors.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 
diff -pruN 1.3.93-2/colored/fore.py 1.4.2-1/colored/fore.py
--- 1.3.93-2/colored/fore.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/colored/fore.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 
diff -pruN 1.3.93-2/colored/hex.py 1.4.2-1/colored/hex.py
--- 1.3.93-2/colored/hex.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/colored/hex.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,268 +1,296 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+_xterm_colors = {
+    "0": "#000000",
+    "1": "#800000",
+    "2": "#008000",
+    "3": "#808000",
+    "4": "#000080",
+    "5": "#800080",
+    "6": "#008080",
+    "7": "#c0c0c0",
+    "8": "#808080",
+    "9": "#ff0000",
+    "10": "#00ff00",
+    "11": "#ffff00",
+    "12": "#0000ff",
+    "13": "#ff00ff",
+    "14": "#00ffff",
+    "15": "#ffffff",
+    "16": "#000000",
+    "17": "#00005f",
+    "18": "#000087",
+    "19": "#0000af",
+    "20": "#0000d7",
+    "21": "#0000ff",
+    "22": "#005f00",
+    "23": "#005f5f",
+    "24": "#005f87",
+    "25": "#005faf",
+    "26": "#005fd7",
+    "27": "#005fff",
+    "28": "#008700",
+    "29": "#00875f",
+    "30": "#008787",
+    "31": "#0087af",
+    "32": "#0087d7",
+    "33": "#0087ff",
+    "34": "#00af00",
+    "35": "#00af5f",
+    "36": "#00af87",
+    "37": "#00afaf",
+    "38": "#00afd7",
+    "39": "#00afff",
+    "40": "#00d700",
+    "41": "#00d75f",
+    "42": "#00d787",
+    "43": "#00d7af",
+    "44": "#00d7d7",
+    "45": "#00d7ff",
+    "46": "#00ff00",
+    "47": "#00ff5f",
+    "48": "#00ff87",
+    "49": "#00ffaf",
+    "50": "#00ffd7",
+    "51": "#00ffff",
+    "52": "#5f0000",
+    "53": "#5f005f",
+    "54": "#5f0087",
+    "55": "#5f00af",
+    "56": "#5f00d7",
+    "57": "#5f00ff",
+    "58": "#5f5f00",
+    "59": "#5f5f5f",
+    "60": "#5f5f87",
+    "61": "#5f5faf",
+    "62": "#5f5fd7",
+    "63": "#5f5fff",
+    "64": "#5f8700",
+    "65": "#5f875f",
+    "66": "#5f8787",
+    "67": "#5f87af",
+    "68": "#5f87d7",
+    "69": "#5f87ff",
+    "70": "#5faf00",
+    "71": "#5faf5f",
+    "72": "#5faf87",
+    "73": "#5fafaf",
+    "74": "#5fafd7",
+    "75": "#5fafff",
+    "76": "#5fd700",
+    "77": "#5fd75f",
+    "78": "#5fd787",
+    "79": "#5fd7af",
+    "80": "#5fd7d7",
+    "81": "#5fd7ff",
+    "82": "#5fff00",
+    "83": "#5fff5f",
+    "84": "#5fff87",
+    "85": "#5fffaf",
+    "86": "#5fffd7",
+    "87": "#5fffff",
+    "88": "#870000",
+    "89": "#87005f",
+    "90": "#870087",
+    "91": "#8700af",
+    "92": "#8700d7",
+    "93": "#8700ff",
+    "94": "#875f00",
+    "95": "#875f5f",
+    "96": "#875f87",
+    "97": "#875faf",
+    "98": "#875fd7",
+    "99": "#875fff",
+    "100": "#878700",
+    "101": "#87875f",
+    "102": "#878787",
+    "103": "#8787af",
+    "104": "#8787d7",
+    "105": "#8787ff",
+    "106": "#87af00",
+    "107": "#87af5f",
+    "108": "#87af87",
+    "109": "#87afaf",
+    "110": "#87afd7",
+    "111": "#87afff",
+    "112": "#87d700",
+    "113": "#87d75f",
+    "114": "#87d787",
+    "115": "#87d7af",
+    "116": "#87d7d7",
+    "117": "#87d7ff",
+    "118": "#87ff00",
+    "119": "#87ff5f",
+    "120": "#87ff87",
+    "121": "#87ffaf",
+    "122": "#87ffd7",
+    "123": "#87ffff",
+    "124": "#af0000",
+    "125": "#af005f",
+    "126": "#af0087",
+    "127": "#af00af",
+    "128": "#af00d7",
+    "129": "#af00ff",
+    "130": "#af5f00",
+    "131": "#af5f5f",
+    "132": "#af5f87",
+    "133": "#af5faf",
+    "134": "#af5fd7",
+    "135": "#af5fff",
+    "136": "#af8700",
+    "137": "#af875f",
+    "138": "#af8787",
+    "139": "#af87af",
+    "140": "#af87d7",
+    "141": "#af87ff",
+    "142": "#afaf00",
+    "143": "#afaf5f",
+    "144": "#afaf87",
+    "145": "#afafaf",
+    "146": "#afafd7",
+    "147": "#afafff",
+    "148": "#afd700",
+    "149": "#afd75f",
+    "150": "#afd787",
+    "151": "#afd7af",
+    "152": "#afd7d7",
+    "153": "#afd7ff",
+    "154": "#afff00",
+    "155": "#afff5f",
+    "156": "#afff87",
+    "157": "#afffaf",
+    "158": "#afffd7",
+    "159": "#afffff",
+    "160": "#d70000",
+    "161": "#d7005f",
+    "162": "#d70087",
+    "163": "#d700af",
+    "164": "#d700d7",
+    "165": "#d700ff",
+    "166": "#d75f00",
+    "167": "#d75f5f",
+    "168": "#d75f87",
+    "169": "#d75faf",
+    "170": "#d75fd7",
+    "171": "#d75fff",
+    "172": "#d78700",
+    "173": "#d7875f",
+    "174": "#d78787",
+    "175": "#d787af",
+    "176": "#d787d7",
+    "177": "#d787ff",
+    "178": "#d7af00",
+    "179": "#d7af5f",
+    "180": "#d7af87",
+    "181": "#d7afaf",
+    "182": "#d7afd7",
+    "183": "#d7afff",
+    "184": "#d7d700",
+    "185": "#d7d75f",
+    "186": "#d7d787",
+    "187": "#d7d7af",
+    "188": "#d7d7d7",
+    "189": "#d7d7ff",
+    "190": "#d7ff00",
+    "191": "#d7ff5f",
+    "192": "#d7ff87",
+    "193": "#d7ffaf",
+    "194": "#d7ffd7",
+    "195": "#d7ffff",
+    "196": "#ff0000",
+    "197": "#ff005f",
+    "198": "#ff0087",
+    "199": "#ff00af",
+    "200": "#ff00d7",
+    "201": "#ff00ff",
+    "202": "#ff5f00",
+    "203": "#ff5f5f",
+    "204": "#ff5f87",
+    "205": "#ff5faf",
+    "206": "#ff5fd7",
+    "207": "#ff5fff",
+    "208": "#ff8700",
+    "209": "#ff875f",
+    "210": "#ff8787",
+    "211": "#ff87af",
+    "212": "#ff87d7",
+    "213": "#ff87ff",
+    "214": "#ffaf00",
+    "215": "#ffaf5f",
+    "216": "#ffaf87",
+    "217": "#ffafaf",
+    "218": "#ffafd7",
+    "219": "#ffafff",
+    "220": "#ffd700",
+    "221": "#ffd75f",
+    "222": "#ffd787",
+    "223": "#ffd7af",
+    "224": "#ffd7d7",
+    "225": "#ffd7ff",
+    "226": "#ffff00",
+    "227": "#ffff5f",
+    "228": "#ffff87",
+    "229": "#ffffaf",
+    "230": "#ffffd7",
+    "231": "#ffffff",
+    "232": "#080808",
+    "233": "#121212",
+    "234": "#1c1c1c",
+    "235": "#262626",
+    "236": "#303030",
+    "237": "#3a3a3a",
+    "238": "#444444",
+    "239": "#4e4e4e",
+    "240": "#585858",
+    "241": "#626262",
+    "242": "#6c6c6c",
+    "243": "#767676",
+    "244": "#808080",
+    "245": "#8a8a8a",
+    "246": "#949494",
+    "247": "#9e9e9e",
+    "248": "#a8a8a8",
+    "249": "#b2b2b2",
+    "250": "#bcbcbc",
+    "251": "#c6c6c6",
+    "252": "#d0d0d0",
+    "253": "#dadada",
+    "254": "#e4e4e4",
+    "255": "#eeeeee"
+}
 
 def HEX(color):
 
-    xterm_colors = {
-        "0": "#000000",
-        "1": "#800000",
-        "2": "#008000",
-        "3": "#808000",
-        "4": "#000080",
-        "5": "#800080",
-        "6": "#008080",
-        "7": "#c0c0c0",
-        "8": "#808080",
-        "9": "#ff0000",
-        "10": "#00ff00",
-        "11": "#ffff00",
-        "12": "#0000ff",
-        "13": "#ff00ff",
-        "14": "#00ffff",
-        "15": "#ffffff",
-        "16": "#000000",
-        "17": "#00005f",
-        "18": "#000087",
-        "19": "#0000af",
-        "20": "#0000d7",
-        "21": "#0000ff",
-        "22": "#005f00",
-        "23": "#005f5f",
-        "24": "#005f87",
-        "25": "#005faf",
-        "26": "#005fd7",
-        "27": "#005fff",
-        "28": "#008700",
-        "29": "#00875f",
-        "30": "#008787",
-        "31": "#0087af",
-        "32": "#0087d7",
-        "33": "#0087ff",
-        "34": "#00af00",
-        "35": "#00af5f",
-        "36": "#00af87",
-        "37": "#00afaf",
-        "38": "#00afd7",
-        "39": "#00afff",
-        "40": "#00d700",
-        "41": "#00d75f",
-        "42": "#00d787",
-        "43": "#00d7af",
-        "44": "#00d7d7",
-        "45": "#00d7ff",
-        "46": "#00ff00",
-        "47": "#00ff5f",
-        "48": "#00ff87",
-        "49": "#00ffaf",
-        "50": "#00ffd7",
-        "51": "#00ffff",
-        "52": "#5f0000",
-        "53": "#5f005f",
-        "54": "#5f0087",
-        "55": "#5f00af",
-        "56": "#5f00d7",
-        "57": "#5f00ff",
-        "58": "#5f5f00",
-        "59": "#5f5f5f",
-        "60": "#5f5f87",
-        "61": "#5f5faf",
-        "62": "#5f5fd7",
-        "63": "#5f5fff",
-        "64": "#5f8700",
-        "65": "#5f875f",
-        "66": "#5f8787",
-        "67": "#5f87af",
-        "68": "#5f87d7",
-        "69": "#5f87ff",
-        "70": "#5faf00",
-        "71": "#5faf5f",
-        "72": "#5faf87",
-        "73": "#5fafaf",
-        "74": "#5fafd7",
-        "75": "#5fafff",
-        "76": "#5fd700",
-        "77": "#5fd75f",
-        "78": "#5fd787",
-        "79": "#5fd7af",
-        "80": "#5fd7d7",
-        "81": "#5fd7ff",
-        "82": "#5fff00",
-        "83": "#5fff5f",
-        "84": "#5fff87",
-        "85": "#5fffaf",
-        "86": "#5fffd7",
-        "87": "#5fffff",
-        "88": "#870000",
-        "89": "#87005f",
-        "90": "#870087",
-        "91": "#8700af",
-        "92": "#8700d7",
-        "93": "#8700ff",
-        "94": "#875f00",
-        "95": "#875f5f",
-        "96": "#875f87",
-        "97": "#875faf",
-        "98": "#875fd7",
-        "99": "#875fff",
-        "100": "#878700",
-        "101": "#87875f",
-        "102": "#878787",
-        "103": "#8787af",
-        "104": "#8787d7",
-        "105": "#8787ff",
-        "106": "#87af00",
-        "107": "#87af5f",
-        "108": "#87af87",
-        "109": "#87afaf",
-        "110": "#87afd7",
-        "111": "#87afff",
-        "112": "#87d700",
-        "113": "#87d75f",
-        "114": "#87d787",
-        "115": "#87d7af",
-        "116": "#87d7d7",
-        "117": "#87d7ff",
-        "118": "#87ff00",
-        "119": "#87ff5f",
-        "120": "#87ff87",
-        "121": "#87ffaf",
-        "122": "#87ffd7",
-        "123": "#87ffff",
-        "124": "#af0000",
-        "125": "#af005f",
-        "126": "#af0087",
-        "127": "#af00af",
-        "128": "#af00d7",
-        "129": "#af00ff",
-        "130": "#af5f00",
-        "131": "#af5f5f",
-        "132": "#af5f87",
-        "133": "#af5faf",
-        "134": "#af5fd7",
-        "135": "#af5fff",
-        "136": "#af8700",
-        "137": "#af875f",
-        "138": "#af8787",
-        "139": "#af87af",
-        "140": "#af87d7",
-        "141": "#af87ff",
-        "142": "#afaf00",
-        "143": "#afaf5f",
-        "144": "#afaf87",
-        "145": "#afafaf",
-        "146": "#afafd7",
-        "147": "#afafff",
-        "148": "#afd700",
-        "149": "#afd75f",
-        "150": "#afd787",
-        "151": "#afd7af",
-        "152": "#afd7d7",
-        "153": "#afd7ff",
-        "154": "#afff00",
-        "155": "#afff5f",
-        "156": "#afff87",
-        "157": "#afffaf",
-        "158": "#afffd7",
-        "159": "#afffff",
-        "160": "#d70000",
-        "161": "#d7005f",
-        "162": "#d70087",
-        "163": "#d700af",
-        "164": "#d700d7",
-        "165": "#d700ff",
-        "166": "#d75f00",
-        "167": "#d75f5f",
-        "168": "#d75f87",
-        "169": "#d75faf",
-        "170": "#d75fd7",
-        "171": "#d75fff",
-        "172": "#d78700",
-        "173": "#d7875f",
-        "174": "#d78787",
-        "175": "#d787af",
-        "176": "#d787d7",
-        "177": "#d787ff",
-        "178": "#d7af00",
-        "179": "#d7af5f",
-        "180": "#d7af87",
-        "181": "#d7afaf",
-        "182": "#d7afd7",
-        "183": "#d7afff",
-        "184": "#d7d700",
-        "185": "#d7d75f",
-        "186": "#d7d787",
-        "187": "#d7d7af",
-        "188": "#d7d7d7",
-        "189": "#d7d7ff",
-        "190": "#d7ff00",
-        "191": "#d7ff5f",
-        "192": "#d7ff87",
-        "193": "#d7ffaf",
-        "194": "#d7ffd7",
-        "195": "#d7ffff",
-        "196": "#ff0000",
-        "197": "#ff005f",
-        "198": "#ff0087",
-        "199": "#ff00af",
-        "200": "#ff00d7",
-        "201": "#ff00ff",
-        "202": "#ff5f00",
-        "203": "#ff5f5f",
-        "204": "#ff5f87",
-        "205": "#ff5faf",
-        "206": "#ff5fd7",
-        "207": "#ff5fff",
-        "208": "#ff8700",
-        "209": "#ff875f",
-        "210": "#ff8787",
-        "211": "#ff87af",
-        "212": "#ff87d7",
-        "213": "#ff87ff",
-        "214": "#ffaf00",
-        "215": "#ffaf5f",
-        "216": "#ffaf87",
-        "217": "#ffafaf",
-        "218": "#ffafd7",
-        "219": "#ffafff",
-        "220": "#ffd700",
-        "221": "#ffd75f",
-        "222": "#ffd787",
-        "223": "#ffd7af",
-        "224": "#ffd7d7",
-        "225": "#ffd7ff",
-        "226": "#ffff00",
-        "227": "#ffff5f",
-        "228": "#ffff87",
-        "229": "#ffffaf",
-        "230": "#ffffd7",
-        "231": "#ffffff",
-        "232": "#080808",
-        "233": "#121212",
-        "234": "#1c1c1c",
-        "235": "#262626",
-        "236": "#303030",
-        "237": "#3a3a3a",
-        "238": "#444444",
-        "239": "#4e4e4e",
-        "240": "#585858",
-        "241": "#626262",
-        "242": "#6c6c6c",
-        "243": "#767676",
-        "244": "#808080",
-        "245": "#8a8a8a",
-        "246": "#949494",
-        "247": "#9e9e9e",
-        "248": "#a8a8a8",
-        "249": "#b2b2b2",
-        "250": "#bcbcbc",
-        "251": "#c6c6c6",
-        "252": "#d0d0d0",
-        "253": "#dadada",
-        "254": "#e4e4e4",
-        "255": "#eeeeee"
-    }
+    # Extend shorthand #ABC -> #AABBCC, like in CSS
+    if len(color) == 4:
+        color = '#'+color[1]*2+color[2]*2+color[3]*2
 
-    # swap keys for values
-    new_xterm_colors = dict(zip(xterm_colors.values(), xterm_colors.keys()))
-    return new_xterm_colors[color]
+    # Try an exact lookup, trying to favor lower numbers
+    # (e.g. find 10 instead of 46 for #00FF00)
+    for xterm_color, hexcolor in _xterm_colors.items():
+        if hexcolor == color:
+            return xterm_color
+
+    # Try to find nearest match using a simple least squares fit.
+    # We could try to factor in human perception bias by weighting
+    # as suggested by <https://stackoverflow.com/a/1847112> but for
+    # now lets just KISS and make upp our minds later, no?
+    # (we do skip the sqrt since we just care for the relative value)
+
+    # The reference color
+    r,g,b = (int(color[1:3],16), int(color[3:5],16), int(color[5:7],16))
+
+    cube = lambda x : x*x
+    f = lambda hex_val,ref : cube(int(hex_val,16) - ref)
+
+    min_cube_d=cube(0xFFFFFF)
+    nearest = '15'
+
+    for k,h in _xterm_colors.items():
+        cube_d = f(h[1:3],r) + f(h[3:5],g) + f(h[5:7],b)
+        if cube_d < min_cube_d:
+            min_cube_d = cube_d
+            nearest = k
+
+    return nearest
diff -pruN 1.3.93-2/colored/__init__.py 1.4.2-1/colored/__init__.py
--- 1.3.93-2/colored/__init__.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/colored/__init__.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 
@@ -9,5 +9,5 @@ from .fore import *
 from .back import *
 from .style import *
 
-__version_info__ = (1, 3, 93)
+__version_info__ = (1, 4, 2)
 __version__ = '{0}.{1}.{2}'.format(*__version_info__)
diff -pruN 1.3.93-2/colored/style.py 1.4.2-1/colored/style.py
--- 1.3.93-2/colored/style.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/colored/style.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 
diff -pruN 1.3.93-2/debian/changelog 1.4.2-1/debian/changelog
--- 1.3.93-2/debian/changelog	2019-10-31 19:28:30.000000000 +0000
+++ 1.4.2-1/debian/changelog	2021-01-13 03:19:16.000000000 +0000
@@ -1,3 +1,20 @@
+colored (1.4.2-1) unstable; urgency=medium
+
+  [ Ondřej Nový ]
+  * d/control: Update Maintainer field with new Debian Python Team
+    contact address.
+  * d/control: Update Vcs-* fields with new Debian Python Team Salsa
+    layout.
+
+  [ Debian Janitor ]
+  * Update standards version to 4.5.0, no changes needed.
+
+  [ Arthur Diniz ]
+  * New upstream version 1.4.2
+  * debian/control: Declare compliance with debian policy 4.5.1
+
+ -- Arthur Diniz <arthurbdiniz@gmail.com>  Wed, 13 Jan 2021 00:19:16 -0300
+
 colored (1.3.93-2) unstable; urgency=medium
 
   [ Arthur Diniz ]
diff -pruN 1.3.93-2/debian/control 1.4.2-1/debian/control
--- 1.3.93-2/debian/control	2019-10-31 19:28:30.000000000 +0000
+++ 1.4.2-1/debian/control	2021-01-13 03:19:16.000000000 +0000
@@ -1,7 +1,7 @@
 Source: colored
 Section: python
 Priority: optional
-Maintainer: Debian Python Modules Team <python-modules-team@lists.alioth.debian.org>
+Maintainer: Debian Python Team <team+python@tracker.debian.org>
 Uploaders:
  Arthur Diniz <arthurbdiniz@gmail.com>,
 Build-Depends:
@@ -9,10 +9,10 @@ Build-Depends:
  dh-python,
  python3-all,
  python3-setuptools,
-Standards-Version: 4.4.1
+Standards-Version: 4.5.1
 Rules-Requires-Root: no
-Vcs-Browser: https://salsa.debian.org/python-team/modules/python-colored
-Vcs-Git: https://salsa.debian.org/python-team/modules/python-colored.git
+Vcs-Browser: https://salsa.debian.org/python-team/packages/python-colored
+Vcs-Git: https://salsa.debian.org/python-team/packages/python-colored.git
 Homepage: https://gitlab.com/dslackw/colored
 Testsuite: autopkgtest-pkg-python
 
diff -pruN 1.3.93-2/README.rst 1.4.2-1/README.rst
--- 1.3.93-2/README.rst	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/README.rst	2019-12-09 10:40:31.000000000 +0000
@@ -12,7 +12,7 @@ Video Demo
 ----------
 
 .. image:: https://gitlab.com/dslackw/images/raw/master/colored/video.png
-    :target: https://asciinema.org/a/10712
+    :target: https://asciinema.org/a/bgxm6KisSvPkPwMsYLyBBJjth
 
 The following colors works with most terminals and terminals emulators.
 ANSI/VT100 escape sequences can be used in every programming languages.
diff -pruN 1.3.93-2/requirements.txt 1.4.2-1/requirements.txt
--- 1.3.93-2/requirements.txt	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/requirements.txt	2019-12-09 10:40:31.000000000 +0000
@@ -1,3 +1,3 @@
 # Python 2, 3
-# Linux OS
+# Linux, Windows OS
 
diff -pruN 1.3.93-2/setup.py 1.4.2-1/setup.py
--- 1.3.93-2/setup.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/setup.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,8 +1,12 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import setuptools
-from distutils.core import setup
+
+try:
+    from setuptools import setup
+except ImportError:
+    from distutils.core import setup
+
 from colored import __version__
 
 
@@ -11,6 +15,7 @@ setup(
     packages=["colored"],
     version=__version__,
     description="Simple library for color and formatting to terminal",
+    long_description=open("README.rst").read(),
     keywords=["color", "colour", "paint", "ansi", "terminal", "linux",
               "python"],
     author="dslackw",
@@ -22,7 +27,11 @@ setup(
         "License :: OSI Approved :: MIT License",
         "Operating System :: POSIX",
         "Operating System :: POSIX :: Linux",
+        "Operating System :: Microsoft",
+        "Operating System :: Microsoft :: Windows",
+        "Operating System :: Microsoft :: Windows :: Windows 10",
         "Operating System :: POSIX :: Other",
+        "Operating System :: OS Independent",
         "Programming Language :: Python",
         "Programming Language :: Python :: 2",
         "Programming Language :: Python :: 2.6",
@@ -34,6 +43,5 @@ setup(
         "Programming Language :: Python :: 3.4",
         "Programming Language :: Python :: 3.5",
         "Programming Language :: Unix Shell",
-        "Topic :: Terminals"],
-    long_description=open("README.rst").read()
+        "Topic :: Terminals"]
 )
diff -pruN 1.3.93-2/tests/test_1.py 1.4.2-1/tests/test_1.py
--- 1.3.93-2/tests/test_1.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/tests/test_1.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 """test foreground and background colors"""
diff -pruN 1.3.93-2/tests/test_2.py 1.4.2-1/tests/test_2.py
--- 1.3.93-2/tests/test_2.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/tests/test_2.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 """test foreground and background colors"""
diff -pruN 1.3.93-2/tests/test_3.py 1.4.2-1/tests/test_3.py
--- 1.3.93-2/tests/test_3.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/tests/test_3.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 """test foreground and background colors"""
diff -pruN 1.3.93-2/tests/test_4.py 1.4.2-1/tests/test_4.py
--- 1.3.93-2/tests/test_4.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/tests/test_4.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 """test foreground and background colors"""
diff -pruN 1.3.93-2/tests/test_5.py 1.4.2-1/tests/test_5.py
--- 1.3.93-2/tests/test_5.py	2018-07-06 19:43:17.000000000 +0000
+++ 1.4.2-1/tests/test_5.py	2019-12-09 10:40:31.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 """test foreground and background colors"""
diff -pruN 1.3.93-2/tests/test_hex_1.py 1.4.2-1/tests/test_hex_1.py
--- 1.3.93-2/tests/test_hex_1.py	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.2-1/tests/test_hex_1.py	2019-12-09 10:40:31.000000000 +0000
@@ -0,0 +1,88 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
+"""Test the nearest matching hex color lookup"""
+
+import time
+from random import randint
+from colored import fg, bg, attr
+from colored.hex import HEX, _xterm_colors
+
+def compare_with_expected( in_hex, expected ):
+    nearest = HEX( in_hex )
+    # Look up the matched hex value (e.g. xterm colors 10 and 46 are
+    # the same hex value)
+    match = _xterm_colors[nearest] == _xterm_colors[expected]
+
+    e_str = '%s%s##%s' % (fg( expected ), bg( expected ), attr('reset'))
+    n_str = '%s%s##%s' % (fg( nearest ), bg( nearest ), attr('reset'))
+    print( "%s: %s => %s = %s" % ( 'pass' if match else 'FAIL', in_hex, n_str, e_str) )
+
+    return match
+
+def main():
+    print( '            Nearest   Expected' )
+    test_set = {
+        '1':  ('#7f0000', '#800000', '#810000'),
+        '2':  ('#007f00', '#008000', '#008100'),
+        '4':  ('#00007f', '#000080', '#000081'),
+        '10': ('#00fe00', '#00ff00', '#01ff00'),
+    }
+
+    all_ok = True
+    for expected, hexes in test_set.items():
+        for hex in hexes:
+            ok = compare_with_expected( hex, expected )
+            all_ok = all_ok and ok
+
+    try:
+        T_sta = time.perf_counter()
+        print( '-'*78 )
+        for y in range(0,0xF):
+            r_row = ''
+            g_row = ''
+            b_row = ''
+            i_row = ''
+            for x in range(0,0xF):
+                c = x + y*0xF
+                hex = '#%02x0000' % (c,)
+                r_row += '%s%s#' % (fg(hex),bg(hex))
+                hex = '#00%02x00' % (c,)
+                g_row += '%s%s#' % (fg(hex),bg(hex))
+                hex = '#0000%02x' % (c,)
+                b_row += '%s%s#' % (fg(hex),bg(hex))
+                hex = '#'+('%02x' % (c,))*3
+                i_row += '%s%s#' % (fg(hex),bg(hex))
+            print( '%s%s %s%s %s%s %s%s' % (r_row,attr('reset'), g_row,attr('reset'), b_row,attr('reset'), i_row,attr('reset')) )
+        dT = time.perf_counter() - T_sta
+        print( 'Lookup time: %0.4f s => %0.4f s/lookup' % (dT, dT / (2*4*0xFF) ) )
+        print( '-'*78 )
+    except Exception as e:
+        print( 'Whopsie, something %s-ish went wrong: %s' % (e.__class__.__name__, e) )
+        import traceback
+        traceback.print_exc()
+        all_ok = False
+
+    # This is just for fun, almost... let's call it a
+    # "non-deterministic check that it doesn't throw any exceptions"
+    try:
+        T_sta = time.perf_counter()
+        from random import randint
+        for y in range(0,20):
+            for x in range(0,30):
+                rnd = randint(0,0xffffff)
+                hex = '#%06x' % (rnd,)
+                hexinv = '#%06x' % (0xffffff-rnd,)
+                print( '%s%s::' % (fg(hexinv),bg(hex)), end='')
+            print( attr('reset') )
+        dT = time.perf_counter() - T_sta
+        print( 'Lookup time: %0.4f s => %0.4f s/lookup' % (dT, dT / (2*30*20) ) )
+    except Exception as e:
+        print( 'Whopsie, something %s-ish went wrong: ' % (e.__class__.__name__, e) )
+        all_ok = False
+
+    return all_ok
+
+if __name__ == "__main__":
+    ok = main()
+    exit( 0 if ok else 1 )
diff -pruN 1.3.93-2/tests/test_hex_2.py 1.4.2-1/tests/test_hex_2.py
--- 1.3.93-2/tests/test_hex_2.py	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.2-1/tests/test_hex_2.py	2019-12-09 10:40:31.000000000 +0000
@@ -0,0 +1,35 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
+"""Test the shorthand #abc hex expansion"""
+
+import time
+from colored.hex import HEX
+
+def main():
+    all_ok = True
+    try:
+        T_sta = time.perf_counter()
+        for r in range(0,0xF):
+            for g in range(0,0xF):
+                for b in range(0,0xF):
+                    short = '#%x%x%x' % (r,g,b)
+                    long = '#%x%x%x%x%x%x' % (r,r,g,g,b,b)
+                    all_ok = all_ok and HEX( long ) == HEX( short )
+                print('.', end='')
+            print('')
+
+        dT = time.perf_counter() - T_sta
+        print( 'Lookup time: %0.4f s => %0.4f s/lookup' % (dT, dT / (2*0xF*0xF*0xF) ) )
+        print( 'pass' if all_ok else 'FAILED' )
+    except Exception as e:
+        print( 'Whopsie, something %s-ish went wrong: %s' % (e.__class__.__name__, e) )
+        import traceback
+        traceback.print_exc()
+        all_ok = False
+
+    return all_ok
+
+if __name__ == "__main__":
+    ok = main()
+    exit( 0 if ok else 1 )
